import time  # Import time module to handle delays
import board  # Import board module to access GPIO pins
import digitalio  # Import digitalio module to handle button input
import usb_hid  # Import usb_hid module to enable USB Human Interface Device (HID) functionality
from adafruit_hid.keyboard import Keyboard  # Import Keyboard class to send key presses
from adafruit_hid.keycode import Keycode  # Import Keycode class to define keypresses

# ---------- SETUP BUTTON INPUT ----------
# Define the pin where the button is connected (GP0 in this case)
button = digitalio.DigitalInOut(board.GP1)  # Change GP0 to your actual button pin

# Set the button as an input device
button.direction = digitalio.Direction.INPUT

# Enable the internal pull-up resistor
# This makes the button default to HIGH (1) when not pressed and LOW (0) when pressed
button.pull = digitalio.Pull.UP  

# ---------- SETUP KEYBOARD EMULATION ----------
# Create a Keyboard object that allows sending keystrokes over USB
keyboard = Keyboard(usb_hid.devices)

# ---------- DEBOUNCE SETTINGS ----------
last_state = button.value  # Store the last known button state
last_press_time = 0  # Store the last time the button was pressed
debounce_delay = 0.05  # Minimum delay (in seconds) between valid button presses to prevent bouncing

# ---------- MAIN LOOP ----------
while True:
    current_state = button.value  # Read the current button state (HIGH or LOW)
    
    # Check if the button state has changed since the last loop iteration
    if last_state != current_state:
        last_state = current_state  # Update last known state
        
        if not current_state:  # If the button is pressed (LOW because of pull-up resistor)
            # Check if enough time has passed since the last press (debounce)
            if time.time() - last_press_time > debounce_delay:
                last_press_time = time.time()  # Update last press time
                
                # Send a keyboard shortcut (Command + Space for Spotlight Search on Mac)
                keyboard.send(Keycode.COMMAND, Keycode.SPACE)  

    # Small delay to reduce CPU usage and avoid rapid unintended key presses
    time.sleep(0.01)
