import board  # Import board module to access pin names
import digitalio  # Import digitalio to work with digital inputs/outputs
import time  # Import time module to handle delays
import usb_hid
from adafruit_hid.keyboard import Keyboard
from adafruit_hid.keycode import Keycode

# Set up the button on pin D7
button = digitalio.DigitalInOut(board.D7)  # Define button on pin D7
button.direction = digitalio.Direction.INPUT  # Set as an input (reading data)
button.pull = digitalio.Pull.UP  # Enable internal pull-up resistor (default HIGH)

# Variable to track previous button state
previous_state = button.value  # Start by storing the initial button state

keyboard = Keyboard(usb_hid.devices)

while True:
    current_state = button.value  # Read the current button state

    # Detect when the button is pressed (goes from HIGH to LOW)
    if previous_state and not current_state:  # Was HIGH, now LOW = Pressed
        print("Hello, World!")  # Print message once
        keyboard.send(Keycode.COMMAND, Keycode.SPACE)  # ⌘ + Space (Spotlight Search)

    # Update previous state for the next loop iteration
    previous_state = current_state

    time.sleep(0.01)  # Small delay to avoid CPU overload
