import board
import analogio
import digitalio
import usb_hid
from adafruit_hid.keyboard import Keyboard
from adafruit_hid.keycode import Keycode
import time

# Initialize Keyboard HID
keyboard = Keyboard(usb_hid.devices)

# Setup Potentiometer on A0
pot = analogio.AnalogIn(board.D0)

# Setup Button on D7 for Axis Toggle
button = digitalio.DigitalInOut(board.D7)
button.direction = digitalio.Direction.INPUT
button.pull = digitalio.Pull.UP  # Pull-up resistor enabled

# Constants
CENTER = 32768
DEADZONE = 10000
current_axis = "X"  # Default to X-axis
button_pressed = False

while True:
    # Read potentiometer value
    pot_value = pot.value - CENTER

    # Read button state (toggle axis)
    if not button.value:  # Button is pressed
        if not button_pressed:  # Debounce: detect first press only
            current_axis = "Y" if current_axis == "X" else "X"
            print(f"Toggled to {current_axis}-axis control")
            button_pressed = True  # Prevent repeated toggling
    else:
        button_pressed = False  # Reset flag when button is released

    # Determine movement based on active axis
    if abs(pot_value) > DEADZONE:
        if current_axis == "X":
            if pot_value > 0:
                keyboard.press(Keycode.KEYPAD_SIX)  # Orbit right
            else:
                keyboard.press(Keycode.KEYPAD_FOUR)  # Orbit left
        else:  # Y-axis mode
            if pot_value > 0:
                keyboard.press(Keycode.KEYPAD_EIGHT)  # Orbit up
            else:
                keyboard.press(Keycode.KEYPAD_TWO)  # Orbit down
    else:
        keyboard.release_all()  # Stop movement when inside deadzone

    time.sleep(0.1)  # Adjust for responsiveness
