import board  # Import board module to access pin names
import digitalio  # Import digitalio to work with digital inputs/outputs
import time  # Import time module to handle delays
import usb_hid
from adafruit_hid.keyboard import Keyboard
from adafruit_hid.keycode import Keycode

# Set up the button on pin D7
button = digitalio.DigitalInOut(board.D7)  # Define button on pin D7
button.direction = digitalio.Direction.INPUT  # Set as an input (reading data)
button.pull = digitalio.Pull.UP  # Enable internal pull-up resistor (default HIGH)

# Variable to track previous button state
previous_state = button.value  # Start by storing the initial button state

keyboard = Keyboard(usb_hid.devices)

toggle = 0 # Var to toggle the state of the button.

while True:
    if toggle == 4: # When the toggle reaches 4, reset it to 0
        toggle = 0

    current_state = button.value  # Read the current button state


    # Detect when the button is pressed (goes from HIGH to LOW)
    if previous_state and not current_state:  # Was HIGH, now LOW = Pressed
        if toggle == 0:
            print("Blender Front")
            keyboard.send(Keycode.KEYPAD_ONE)  # Sends the Numbad one key - in Blender this is the front view
        elif toggle == 1:
            print("Blender Side")
            keyboard.send(Keycode.KEYPAD_THREE)  # Sends the Numbad three key - in Blender this is the side view
        elif toggle == 2:
            print("Blender Top")
            keyboard.send(Keycode.KEYPAD_SEVEN)  # Sends the Numbad seven key - in Blender this is the top view
        else:
            print("Blender Camera")  # Print message once
            keyboard.send(Keycode.KEYPAD_ZERO)  # Sends the Numbad zero key - in Blender this is the camera view
        toggle = toggle + 1 # After each press, increment the toggle

    # Update previous state for the next loop iteration
    previous_state = current_state

    time.sleep(0.01)  # Small delay to avoid CPU overload