import board  # Import board module to access pin names
import digitalio  # Import digitalio to work with digital inputs/outputs
import time  # Import time module to handle delays
import usb_hid
from adafruit_hid.keyboard import Keyboard
from adafruit_hid.keycode import Keycode

import displayio
import terminalio
from adafruit_display_text import label
from adafruit_displayio_ssd1306 import SSD1306
import i2cdisplaybus

# Set up the button on pin D7
button = digitalio.DigitalInOut(board.D7)  # Define button on pin D7
button.direction = digitalio.Direction.INPUT  # Set as an input (reading data)
button.pull = digitalio.Pull.UP  # Enable internal pull-up resistor (default HIGH)

# Variable to track previous button state
previous_state = button.value  # Start by storing the initial button state

keyboard = Keyboard(usb_hid.devices)

toggle = 0 # Var to toggle the state of the button.

# Screen Stuff

# Release any previously used displays
displayio.release_displays()

# Set up I2C and display
i2c = board.I2C()  # Uses GP17 (SCL) and GP16 (SDA) by default
display_bus = i2cdisplaybus.I2CDisplayBus(i2c, device_address=0x3C)
display = SSD1306(display_bus, width=128, height=64)

display.rotation = 180

# Create text label
text_area = label.Label(terminalio.FONT, text="Hello World", color=0xFFFFFF, x=30, y=30)

# Show it on the screen
group = displayio.Group()
group.append(text_area)
display.root_group = group  # New method in CircuitPython 9.x

while True:
    if toggle == 4: # When the toggle reaches 4, reset it to 0
        toggle = 0

    current_state = button.value  # Read the current button state

    # Detect when the button is pressed (goes from HIGH to LOW)
    if previous_state and not current_state:  # Was HIGH, now LOW = Pressed
        if toggle == 0:
            print("Blender Front")
            text_area.text = "Blender Front"
            keyboard.send(Keycode.KEYPAD_ONE)  # Sends the Numbad one key - in Blender this is the front view
        elif toggle == 1:
            print("Blender Side")
            text_area.text = "Blender Side"
            keyboard.send(Keycode.KEYPAD_THREE)  # Sends the Numbad three key - in Blender this is the side view
        elif toggle == 2:
            print("Blender Top")
            text_area.text = "Blender Top"
            keyboard.send(Keycode.KEYPAD_SEVEN)  # Sends the Numbad seven key - in Blender this is the top view
        else:
            print("Blender Camera")  # Print message once
            text_area.text = "Blender Camera"
            keyboard.send(Keycode.KEYPAD_ZERO)  # Sends the Numbad zero key - in Blender this is the camera view
        
        toggle = toggle + 1 # After each press, increment the toggle
        display.root_group = group  # Refresh display



    # Update previous state for the next loop iteration
    previous_state = current_state

    time.sleep(0.01)  # Small delay to avoid CPU overload